@@ -90,19 +90,17 @@ impl IntoOpt for f64 {
     }
 }
 
-pub fn write_header<T: std::fmt::Write, O: IntoOpt>(
+///
+/// Write the svg header with the specified width and viewport.
+///
+pub fn write_header<T: std::fmt::Write>(
     mut w: T,
-    dim: [O; 2],
+    dim: [f64; 2],
     viewbox: [f64; 2],
 ) -> std::fmt::Result {
     write!(w, "<svg class=\"poloto\" ")?;
-    if let Some(x) = dim[0].create() {
-        write!(w, "width=\"{}\" ", x)?;
-    }
-    if let Some(y) = dim[1].create() {
-        write!(w, "height=\"{}\" ", y)?;
-    }
-
+    write!(w, "width=\"{}\" ", dim[0])?;
+    write!(w, "height=\"{}\" ", dim[1])?;
     write!(
         w,
         "viewBox=\"0 0 {} {}\" xmlns=\"http://www.w3.org/2000/svg\">",
@@ -145,3 +143,11 @@ impl<PF: PlotFmtAll> SimpleTheme for Plotter<'_, PF> {
         )
     }
 }
+
+///
+/// Based on a svg viewport and a desired width, determine the height.
+///
+pub fn determine_height_from_width(viewport: [f64; 2], width: f64) -> f64 {
+    let [xx, yy] = viewport;
+    width * (yy / xx)
+}
